aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKamil Dudka <kdudka@redhat.com>2015-09-04 16:10:44 +0200
committerKamil Dudka <kdudka@redhat.com>2015-09-04 16:12:26 +0200
commit0e91737615f85e1a51ca84cfd5a5a804b4a6819d (patch)
treeb967bf2418abdd8d79874e720caffe7bce3cfa7d
parent7380433d6a2f4aaec8dfcacfffadc260b417c7a3 (diff)
Revert "has: generate the curl/has.h header"
This reverts commit a60bde79f9adeb135d5c642a07f0d783fbfbbc25 I have pushed by mistake. Apologies for my incompetent use of the git repo!
-rw-r--r--docs/libcurl/Makefile.am2
-rwxr-xr-xdocs/libcurl/symbols.pl (renamed from include/curl/has.pl)66
-rw-r--r--include/curl/Makefile.am17
3 files changed, 19 insertions, 66 deletions
diff --git a/docs/libcurl/Makefile.am b/docs/libcurl/Makefile.am
index 677fb94ad..5456ee418 100644
--- a/docs/libcurl/Makefile.am
+++ b/docs/libcurl/Makefile.am
@@ -90,7 +90,7 @@ dist_m4macro_DATA = libcurl.m4
CLEANFILES = $(HTMLPAGES) $(PDFPAGES) $(TESTS) libcurl-symbols.3
EXTRA_DIST = $(man_MANS) $(HTMLPAGES) index.html $(PDFPAGES) ABI \
- symbols-in-versions mksymbolsmanpage.pl
+ symbols-in-versions symbols.pl mksymbolsmanpage.pl
MAN2HTML= roffit --mandir=. < $< >$@
SUFFIXES = .3 .html
diff --git a/include/curl/Makefile.am b/include/curl/Makefile.am
index f804bbb24..86e8b7834 100644
--- a/include/curl/Makefile.am
+++ b/include/curl/Makefile.am
@@ -5,7 +5,7 @@
# | (__| |_| | _ <| |___
# \___|\___/|_| \_\_____|
#
-# Copyright (C) 1998 - 2015, Daniel Stenberg, <daniel@haxx.se>, et al.
+# Copyright (C) 1998 - 2011, Daniel Stenberg, <daniel@haxx.se>, et al.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
@@ -21,7 +21,7 @@
###########################################################################
pkginclude_HEADERS = \
curl.h curlver.h easy.h mprintf.h stdcheaders.h multi.h \
- typecheck-gcc.h curlbuild.h curlrules.h has.h
+ typecheck-gcc.h curlbuild.h curlrules.h
pkgincludedir= $(includedir)/curl
@@ -40,19 +40,14 @@ pkgincludedir= $(includedir)/curl
#
# curlbuild.h.dist is not included in the source code distribution archive.
-EXTRA_DIST = curlbuild.h.in has.pl
+EXTRA_DIST = curlbuild.h.in
-DISTCLEANFILES = curlbuild.h has.h
-
-has.h: $(top_srcdir)/docs/libcurl/symbols-in-versions has.pl
- @@PERL@ has.pl < $(top_srcdir)/docs/libcurl/symbols-in-versions > has.h
+DISTCLEANFILES = curlbuild.h
checksrc:
- @@PERL@ $(top_srcdir)/lib/checksrc.pl -Wcurlbuild.h -D$(top_srcdir)/include/curl $(pkginclude_HEADERS) curlbuild.h.in
+ @@PERL@ $(top_srcdir)/lib/checksrc.pl -Wcurlbuild.h -D$(top_srcdir)/include/curl $(pkginclude_HEADERS) $(EXTRA_DIST)
if CURLDEBUG
# for debug builds, we scan the sources on all regular make invokes
-all-local: has.h checksrc
-else
-all-local: has.h
+all-local: checksrc
endif
diff --git a/include/curl/has.pl b/docs/libcurl/symbols.pl
index fab6650f8..a7b76e239 100755
--- a/include/curl/has.pl
+++ b/docs/libcurl/symbols.pl
@@ -6,7 +6,7 @@
# | (__| |_| | _ <| |___
# \___|\___/|_| \_\_____|
#
-# Copyright (C) 2011-2015, Daniel Stenberg, <daniel@haxx.se>, et al.
+# Copyright (C) 2011, Daniel Stenberg, <daniel@haxx.se>, et al.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
@@ -30,18 +30,19 @@
# using applications to do preprocessor checks for specific libcurl defines,
# and yet make the code clearly show what the macro is used for.
#
# Run this script and generate curl/has.h and then use that header in
# a fashion similar to:
#
-# #include <curl/has.h>
+# #include "libcurl-symbols.h"
#
-# #if CURL_HAS(CURLOPT_MUTE)
+# #if LIBCURL_HAS(CURLOPT_MUTE)
# has mute
# #else
# no mute
# #endif
#
#
+open F, "<symbols-in-versions";
sub str2num {
my ($str)=@_;
@@ -51,54 +52,17 @@ sub str2num {
}
print <<EOS
-#ifndef __CURL_HAS_H
-#define __CURL_HAS_H
-/***************************************************************************
- * _ _ ____ _
- * Project ___| | | | _ \\| |
- * / __| | | | |_) | |
- * | (__| |_| | _ <| |___
- * \\___|\\___/|_| \\_\\_____|
- *
- * Copyright (C) 1998 - 2015, Daniel Stenberg, <daniel@haxx.se>, et al.
- *
- * This software is licensed as described in the file COPYING, which
- * you should have received as part of this distribution. The terms
- * are also available at http://curl.haxx.se/docs/copyright.html.
- *
- * You may opt to use, copy, modify, merge, publish, distribute and/or sell
- * copies of the Software, and permit persons to whom the Software is
- * furnished to do so, under the terms of the COPYING file.
- *
- * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
- * KIND, either express or implied.
- *
- ***************************************************************************/
-/*
- * This file is generated. Do not edit by hand. Edit
- * docs/libcurl/symbols-in-versions and regenerate this with has.pl
- */
-#include <curl/curlver.h>
-/*
- * #include <curl/has.h>
- *
- * #if CURL_HAS(CURLOPT_MUTE)
- * use_mute();
- * #else
- * without_mute();
- * #endif
- */
-#define CURL_HAS_IN(x,y) \\
- (defined(CURLHAS_ ## x ) && (CURLHAS_ ## x <= y) && \\
- (!defined(CURLHAS_ ## x ## _L) || ( CURLHAS_ ## x ## _L >= y)))
+#include <curl/curl.h>
-#define CURL_HAS(x) CURL_HAS_IN(x, LIBCURL_VERSION_NUM)
+#define LIBCURL_HAS(x) \\
+ (defined(x ## _FIRST) && (x ## _FIRST <= LIBCURL_VERSION_NUM) && \\
+ (!defined(x ## _LAST) || ( x ## _LAST >= LIBCURL_VERSION_NUM)))
EOS
;
-while(<STDIN>) {
+while(<F>) {
if(/^(CURL[^ ]*)[ \t]*(.*)/) {
my ($sym, $vers)=($1, $2);
@@ -121,22 +85,16 @@ while(<STDIN>) {
my $inum = str2num($intr);
print <<EOS
-#define CURLHAS_${sym} $inum /* $intr */
+#define ${sym}_FIRST $inum /* Added in $intr */
EOS
;
my $irm = str2num($rm);
if($rm) {
print <<EOS
-#define CURLHAS_${sym}_L $irm /* Last $rm */
+#define ${sym}_LAST $irm /* Last featured in $rm */
EOS
;
}
}
}
-
-print <<EOS
-#endif /* __CURL_HAS_H */
-
-EOS
- ;
@@ -30,18 +30,19 @@
# and yet make the code clearly show what the macro is used for.
#
-# Run this script and generate curl/has.h and then use that header in
+# Run this script and generate libcurl-symbols.h and then use that header in
# a fashion similar to:
#